@@ -70,6 +70,8 @@ __all__ = (
     "TargetDbTypeType",
     "TestConnectionSucceedsWaiterName",
     "ServiceName",
+    "PaginatorName",
+    "WaiterName",
 )
 
 
@@ -411,10 +413,12 @@ ServiceName = Literal[
     "transcribe",
     "transfer",
     "translate",
+    "voice-id",
     "waf",
     "waf-regional",
     "wafv2",
     "wellarchitected",
+    "wisdom",
     "workdocs",
     "worklink",
     "workmail",
@@ -422,3 +426,28 @@ ServiceName = Literal[
     "workspaces",
     "xray",
 ]
+PaginatorName = Literal[
+    "describe_certificates",
+    "describe_connections",
+    "describe_endpoint_types",
+    "describe_endpoints",
+    "describe_event_subscriptions",
+    "describe_events",
+    "describe_orderable_replication_instances",
+    "describe_replication_instances",
+    "describe_replication_subnet_groups",
+    "describe_replication_task_assessment_results",
+    "describe_replication_tasks",
+    "describe_schemas",
+    "describe_table_statistics",
+]
+WaiterName = Literal[
+    "endpoint_deleted",
+    "replication_instance_available",
+    "replication_instance_deleted",
+    "replication_task_deleted",
+    "replication_task_ready",
+    "replication_task_running",
+    "replication_task_stopped",
+    "test_connection_succeeds",
+]
